const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# traola bat goiburu nagusirako",
    "## two hashes for second heading": "## bi traola bigarren goibururako",
    "### three hashes for third heading": "### hiru traola hirugarren goibururako",
    "**double star for bold**": "**izarño bikoitza letra loditzeko**",
    "*single star for italic*": "*izarño bakarra letra etzatzeko*",
    "--- for a horizontal rule": "--- lerro horizontala egiteko",
    "1 day": "egun 1",
    "1 hour": "ordu 1",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Trazuaren marra eredua definitzen duen komaz bereizitako zenbakien zerrenda. Adib.: \"5, 10, 15\".",
    "About": "Honi buruz",
    "Action not allowed :(": "Ekintza hau ez da onartzen :(",
    "Activate slideshow mode": "Aktibatu aurkezpen modua",
    "Add a layer": "Gehitu geruza bat",
    "Add a line to the current multi": "Gehitu lerro bat uneko multiari",
    "Add a new property": "Gehitu jabe berri bat",
    "Add a polygon to the current multi": "Gehitu poligono bat uneko multiari",
    "Add image URL": "Gehitu irudiaren URLa",
    "Add": "Gehitu",
    "Advanced actions": "Ekintza aurreratuak",
    "Advanced properties": "Propietate aurreratuak",
    "All data and settings of the map": "Maparen datu eta ezarpen guztiak",
    "All properties are imported.": "Propietate guztiak inportatu dira.",
    "Allow interactions": "Baimendu interakzioak",
    "Allow scroll wheel zoom?": "Saguaren errobera erabiliz zoom egitea baimendu?",
    "always": "beti",
    "Animated transitions": "Trantsizio animatuak",
    "Are you sure you want to cancel your changes?": "Ziur aldaketak bertan behera utzi nahi dituzula?",
    "Are you sure you want to clone this map and all its datalayers?": "Ziur mapa hau eta bere datu-geruza guztiak klonatu nahi dituzula?",
    "Are you sure you want to delete the feature?": "Ziur entitatea ezabatu nahi duzula?",
    "Are you sure you want to delete this layer?": "Ziur geruza hau ezabatu nahi duzula?",
    "Are you sure you want to delete this map?": "Ziur mapa hau ezabatu nahi duzula?",
    "Are you sure you want to delete this property on all the features?": "Ziur propietate hau entitate guztietan ezabatu nahi duzula?",
    "Are you sure you want to restore this version?": "Ziur bertsio hau leheneratu nahi duzula?",
    "Attach the map to my account": "Erantsi mapa nire kontuan",
    "attribution": "atribuzioa",
    "Auto": "Automatikoa",
    "Automatic": "Automatikoa",
    "Autostart when map is loaded": "Abiarazi automatikoki mapa kargatzen denean",
    "Back to preview": "Itzuli aurrebistara",
    "Background overlay url": "Atzeko planoan gainjartzeko URLa",
    "Ball": "Baloia",
    "Bring feature to center": "Ekarri entitatea erdigunera",
    "Browse data": "Arakatu datuak",
    "by": "egilea",
    "Cache proxied request": "Cache proxy eskaera",
    "Cancel edits": "Utzi aldaketak",
    "Caption": "Testua",
    "Center map on your location": "Zentratu mapa zure kokapenean",
    "Change map background": "Aldatu maparen atzeko planoa",
    "Change tilelayers": "Aldatu lauzen geruza",
    "Change": "Aldatu",
    "Choose the data format": "Aukeratu data-formatua",
    "Choropleth breakpoints": "Koropletaren eten-puntuak",
    "Choropleth classes": "Koropleta motak",
    "Choropleth color palette": "Koropletaren kolore paleta",
    "Choropleth mode": "Koropleta mota",
    "Choropleth property value": "Koropletaren propietate-balioa",
    "Choropleth": "Koropleta",
    "Circle": "Borobila",
    "clear": "garbitu",
    "Click last point to finish shape": "Egin klik azken puntuan forma amaitzeko",
    "Click to add a marker": "Egin klik markagailu bat gehitzeko",
    "Click to continue drawing": "Egin klik marrazten jarraitzeko",
    "Click to edit": "Egin klik editatzeko",
    "Click to start drawing a line": "Egin klik lerro bat marrazten hasteko",
    "Click to start drawing a polygon": "Egin klik poligono bat marrazten hasteko",
    "Clone of {name}": "{name}-ren klona",
    "Clone this feature": "Klonatu entitate hau",
    "Clone this map": "Klonatu mapa hau",
    "Clone": "Klonatu",
    "Close": "Itxi",
    "Clustered": "Taldekatuta",
    "Clustering radius": "Taldearen erradioa",
    "collapsed": "taldekatua",
    "color": "kolorea",
    "Comma separated list of numbers, including min and max values.": "Komaz bereizitako zenbakien zerrenda, gutxieneko eta gehienezko balioak barne.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Komaz bereizitako propietateen zerrenda entitateak ordenatzeko irizpide gisa erabiltzeko. Ordena aldatzeko, jarri minus ikurra (-) aurretik. Adib. niretekla,-bestetekla.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Koma, tabulazioa edo puntu eta komaz bereizitako balioak. SRS WGS84 inplizitua dago. Puntuen geometriak bakarrik inportatzen dira. Inportazioak zutabeen goiburuak aztertuko ditu goiburuaren hasieran «lat» eta «lon» aipatzearren, maiuskulak eta minuskulak bereizten dituena. Beste zutabe guztiak propietate gisa inportatzen dira.",
    "Congratulations, your map has been created!": "Zorionak, zure mapa ondo sortu da!",
    "Continue line": "Lerro jarrai",
    "Coordinates": "Koordenatuak",
    "copy": "kopiatu",
    "Credits": "Kredituak",
    "Current map view": "Uneko maparen ikuspegia",
    "Current view instead of default map view?": "Uneko ikuspegia maparen ikuspegi lehenetsiaren ordez?",
    "Custom background": "Atzeko plano pertsonalizatua",
    "Custom overlay": "Gainjartze pertsonalizatua",
    "dash array": "marren matrizea",
    "Data is browsable": "Datuak araka daitezke",
    "Datalayers": "Datu-geruzak",
    "Default interaction options": "Interakzio-aukera lehenetsiak",
    "Default properties": "Propietate lehenetsiak",
    "Default shape properties": "Formen propietate lehenetsiak",
    "Default view": "Ikuspegi lehenetsia",
    "Default zoom level": "Zoom maila lehenetsia",
    "Default": "Lehenetsia",
    "Default: name": "Lehenetsia: izena",
    "Define link to open in a new window on polygon click.": "Definitu esteka poligonoan klik eginez leiho berri batean irekitzeko.",
    "define": "definitu",
    "Delay between two transitions when in play mode": "Bi trantsizioren arteko atzerapena erreprodukzio moduan dagoenean",
    "Delete layer": "Ezabatu geruza",
    "Delete this feature": "Ezabatu entitate hau",
    "Delete this shape": "Ezabatu forma hau",
    "Delete this vertex (Alt+Click)": "Ezabatu erpin hau (Alt+Klik)",
    "Delete": "Ezabatu",
    "description": "deskribapena",
    "Direct link": "Esteka zuzena",
    "Directions from here": "Hemendik jarraibideak",
    "Display label": "Bistaratu etiketa",
    "Display measure": "Bistaratu neurria",
    "display name": "bistaratu izena",
    "Display on load": "Bistaratu kargatzean",
    "Display the control to open OpenStreetMap editor": "Bistaratu OpenStreetMap editorea irekitzeko kontrola",
    "Display the embed control": "Bistaratu kapsulatzeko kontrola",
    "Display the fullscreen control": "Bistaratu pantaila osoko kontrola",
    "Display the locate control": "Bistaratu lokalizazio kontrola",
    "Display the measure control": "Bistaratu neurrien kontrola",
    "Display the search control": "Bistaratu bilaketa-kontrola",
    "Display the star map button": "Bistaratu gogoko mapen botoia",
    "Display the tile layers control": "Bistaratu lauzen geruzaren kontrola",
    "Display the zoom control": "Bistaratu zoom kontrola",
    "Do you want to display a caption bar?": "Epigrafeen barra bistaratu nahi duzu?",
    "Do you want to display a minimap?": "Minimapa erakutsi nahi duzu?",
    "Do you want to display a panel on load?": "Kargatzean panel bat bistaratu nahi duzu?",
    "Do you want to display caption menus?": "Epigrafeen menuak erakutsi nahi dituzu?",
    "Do you want to display popup footer?": "Popup-oina bistaratu nahi duzu?",
    "Do you want to display the scale control?": "Eskalaren kontrola bistaratu nahi duzu?",
    "Do you want to display the «more» control?": "«Gehiago» kontrola bistaratu nahi duzu?",
    "Download": "Deskargatu",
    "Drag to reorder": "Arrastatu berrantolatzeko",
    "Draw a marker": "Jarri markagailu bat",
    "Draw a polygon": "Marraztu poligono bat",
    "Draw a polyline": "Marraztu polilinea bat",
    "Drawing": "Marrazten",
    "Drop": "Jaregin",
    "Dynamic properties": "Propietate dinamikoak",
    "Dynamic": "Dinamikoa",
    "Edit feature's layer": "Editatu entitateen geruza",
    "Edit properties in a table": "Editatu propietateak taula batean",
    "Edit the title of the map": "Editatu maparen izenburua",
    "Edit this feature": "Editatu entitate hau",
    "Edit": "Editatu",
    "Embed and link options": "Kapsulatzeko eta estekatzeko aukerak",
    "Embed the map": "Kapsulatu mapa",
    "Emoji & Character": "Emoji eta karaktereak",
    "Empty": "Hutsa",
    "Equidistant": "Ekidistantea",
    "Error in the overlay URL": "Errorea gainjarritako URLan",
    "Error in the tilelayer URL": "Errore bat lauzen geruzaren URLan",
    "Exit Fullscreen": "Irten pantaila osotik",
    "expanded": "hedatua",
    "Extract shape to separate feature": "Atera ezazu forma entitatea bereizteko",
    "Feature identifier key": "Entitatea identifikatzeko gakoa",
    "Feature properties": "Entitatearen propietateak",
    "Fetch data each time map view changes.": "Lortu datuak mapa-ikuspegia aldatzen den bakoitzean.",
    "fill color": "betetzeko kolorea",
    "fill opacity": "betegarriaren opakutasuna",
    "fill": "bete",
    "Fit all data": "Egokitu datu guztiak",
    "Format": "Formatua",
    "From zoom": "Zoometik",
    "full backup": "babeskopia osoa",
    "Generic": "Generikoa",
    "GeoRSS (only link)": "GeoRSS (esteka bakarrik)",
    "GeoRSS (title + image)": "GeoRSS (titulua + irudia)",
    "Go to \"{coords}\"": "Joan \"{coords}\"-ra",
    "Go to the homepage": "Joan hasierako orrira",
    "Go to «{feature}»": "Joan «{feature}» atalera",
    "Heatmap intensity property": "Bero-maparen intentsitatearen propietatea",
    "Heatmap radius": "Bero-maparen erradioa",
    "Heatmap": "Bero-mapa",
    "height": "altuera",
    "Help": "Laguntza",
    "hidden": "ezkutuan",
    "Hide controls": "Ezkutatu kontrolak",
    "Home": "Hasiera",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Zenbat sinplifikatu poli-linea zoom maila bakoitzean (gehiago = errendimendu hobea eta itxura leunagoa, gutxiago = zehatzagoa)",
    "icon opacity": "ikonoaren opakutasuna",
    "Icon shape": "Ikonoaren forma",
    "Icon symbol": "Ikonoaren ikurra",
    "If false, the polygon or line will act as a part of the underlying map.": "Gezurra bada, poligonoak edo lerroak azpiko maparen zati gisa jardungo du.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Altuera pertsonalizatua duen markoa (px-tan): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Altuera eta zabalera pertsonalizatua duen markoa (px-tan):  {{{http://iframe.url.com|height*width}}}",
    "iframe": "markoa",
    "Iframe: {{{http://iframe.url.com}}}": "markoa: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Zabalera pertsonalizatua duen irudia (px-tan):  {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Irudia: {{http://image.url.com}}",
    "Import data": "Inportatu datuak",
    "Import in a new layer": "Inportatu geruza berri batean",
    "Imports all umap data, including layers and settings.": "Umap-en datu guztiak inportatzen ditu, geruzak eta ezarpenak barne.",
    "Include full screen link?": "Pantaila osoko esteka sartu nahi duzu?",
    "Inherit": "Heredatu",
    "inherit": "heredatu",
    "Interaction options": "Interakzio-aukerak",
    "Invalid latitude or longitude": "Latitude edo longitude baliogabea",
    "Invalid umap data in {filename}": "Umap-en datu baliogabeak {filename}-n",
    "Invalid umap data": "Umap datu baliogabeak",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Mantendu uneko geruzak ikusgai",
    "kilometers": "kilometroak",
    "km": "km",
    "Label direction": "Etiketaren norabidea",
    "Label key": "Etiketa-gakoa",
    "Labels are clickable": "Etiketak klik egin daitezke",
    "Latest feature": "Azken entitatea",
    "Latitude": "Latitudea",
    "Layer properties": "Geruzaren propietateak",
    "Layer": "Geruza",
    "Licence": "Lizentzia",
    "licence": "lizentzia",
    "Limit bounds": "Mugak",
    "Link to view the map": "Mapa ikusteko esteka",
    "Link to…": "Estekatu honi...",
    "Link with text: [[http://example.com|text of the link]]": "Testua duen esteka: [[http://adibidea.com|estekaren testua]]",
    "Long credits": "Kreditu luzeak",
    "Longitude": "Longitudea",
    "Make main shape": "Egin forma nagusia",
    "Manage layers": "Kudeatu geruzak",
    "Manual": "Eskuliburua",
    "Map background credits": "Maparen atzeko planoaren kredituak",
    "Map has been attached to your account": "Mapa erantsi da zure kontuan",
    "Map has been saved!": "Mapa gorde da!",
    "Map has been starred": "Mapa hau gogokoa da",
    "Map has been unstarred": "Mapa hau gogokoetatik kendu da",
    "Map user content has been published under licence": "Maparen erabiltzaileen edukia lizentziapean argitaratu da",
    "Map's editors": "Maparen editoreak",
    "Map's owner": "Maparen jabea",
    "max East": "Ekialdea maximoa",
    "max North": "Iparra maximoa",
    "max South": "Hegoa maximoa",
    "max West": "Mendebaldea maximoa",
    "max zoom": "zoom maximoa",
    "Measure distances": "Neurtu distantziak",
    "Merge lines": "Bateratu lerroak",
    "mi": "mila",
    "miles": "mila",
    "min zoom": "zoom minimoa",
    "More controls": "Kontrol gehiago",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Baliozko CSS balio bat izan behar du (adib.: DarkBlue edo #123456)",
    "name": "izena",
    "nautical miles": "itsas milia",
    "never": "inoiz ez",
    "new window": "leiho berria",
    "next": "hurrengoa",
    "NM": "itsas mila",
    "No cache": "Cacherik gabe",
    "No licence has been set": "Ez da lizentziarik ezarri",
    "No results": "Emaitzarik ez",
    "no": "ez",
    "No.": "Ez.",
    "None": "Bat ere ez",
    "Number of desired classes (default 5)": "Nahi diren klase kopurua (lehenetsia 5)",
    "On the bottom": "Behean",
    "On the left": "Ezkerrean",
    "On the right": "Eskuinean",
    "On the top": "Goian",
    "Only visible layers' data": "Ikusgai dauden geruzen datuak soilik",
    "opacity": "opakutasuna",
    "Opacity": "Opakutasuna",
    "Open current feature on load": "Ireki uneko entitatea kargatzean",
    "Open link in…": "Ireki esteka hemen...",
    "Open share & download panel": "Ireki partekatzeko eta deskargatzeko panela",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ireki mapa hau mapa-editore batean OpenStreetMap-i datu zehatzagoak emateko",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Bero-maparen intentsitate propietate aukerakoa",
    "Optional. Same as color if not set.": "Aukerakoa. Kolore berdina ezarri ez bada.",
    "Optional.": "Aukerakoa.",
    "Override clustering radius (default 80)": "Gainidatzi multzokatze-erradioa (80 lehenetsia)",
    "Override heatmap radius (default 25)": "Gainidatzi bero-maparen erradioa (lehenetsia 25)",
    "parent window": "leiho nagusia",
    "Paste your data here": "Itsatsi zure datuak hemen",
    "Permalink": "Esteka iraunkorra",
    "Permanent credits background": "Kredituak beti atzeko planoan",
    "Permanent credits": "Kreditu iraunkorrak",
    "Please be sure the licence is compliant with your use.": "Mesedez, ziurtatu lizentzia zure erabilerarekin bat datorrela.",
    "Please choose a format": "Aukeratu formatu bat",
    "Please enter the name of the property": "Sartu propietate honen izena",
    "Please enter the new name of this property": "Sartu propietate honen izen berria",
    "Please save the map first": "Gorde mapa lehenik",
    "Popup (large)": "Laster-leiho (handia)",
    "Popup content style": "Laster-leihoaren edukiaren estiloa",
    "Popup content template": "Laster-leihoaren edukiaren txantiloia",
    "Popup shape": "Laster-leihoaren forma",
    "Popup": "Laster-leihoa",
    "Powered by uMap": "uMap-ek bultzatuta",
    "previous": "aurrekoa",
    "Problem in the response": "Arazoa erantzunean",
    "Properties imported:": "Inportatutako propietateak:",
    "Provide an URL here": "Eman URL bat hemen",
    "Proxy request": "Proxy eskaera",
    "Quantiles": "Kuantilak",
    "Recent": "Duela gutxikoa",
    "Remote data": "Urrutiko datuak",
    "Remove shape from the multi": "Kendu forma multitik",
    "Replace layer content": "Ordeztu geruzaren edukia",
    "Restore this version": "Berreskuratu bertsio hau",
    "Save current edits": "Gorde uneko aldaketak",
    "Save map": "Gorde mapa",
    "Save this center and zoom": "Gorde zentro hau eta zoom-maila",
    "Save this location as new feature": "Gorde kokapen hau entitate berri gisa",
    "Save": "Gorde",
    "Saved center and zoom": "Zentroa eta zoom-maila gordeta",
    "Search location": "Bilatu tokia",
    "Search": "Bilatu",
    "Secret edit link:": "Editatzeko esteka sekretua:",
    "See full screen": "Ikusi pantaila osoan",
    "See on OpenStreetMap": "Ikusi OpenStreetMap-en",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Ezarri faltsu gisa geruza hau ezkutatzeko diapositiba-aurkezpenetik, datu-arakatzailetik, popup nabigaziotik...",
    "settings": "ezarpenak",
    "Shape properties": "Formaren propietateak",
    "Share and download": "Partekatu eta deskargatu",
    "Share this link to open a customized map view": "Partekatu esteka hau mapa-ikuspegi pertsonalizatu bat irekitzeko",
    "Short credits": "Kreditu laburrak",
    "Short link": "Esteka laburra",
    "Show this layer in the caption": "Erakutsi geruza hau epigrafean",
    "Show/hide layer": "Erakutsi/Ezkutatu geruza",
    "Side panel": "Alboko panela",
    "Simple link: [[http://example.com]]": "Esteka sinplea: [[http://adibidea.com]]",
    "Simplify": "Sinplifikatu",
    "Skipping unknown geometry.type: {type}": "geometry.type ezezaguna saltatzen: {type}",
    "Slideshow": "Aurkezpena",
    "Sort key": "Ordenatzeko tekla",
    "Split line": "Bereizteko lerroa",
    "Star this map": "Markatu gogoko gisa",
    "Start a hole here": "Hasi zulo bat hemen",
    "Start slideshow": "Hasi diaporama",
    "Stop editing": "Utzi editatzeari",
    "Stop slideshow": "Gelditu aurkezpena",
    "Street": "Kalea",
    "stroke": "trazua",
    "Supported scheme": "Onartutako eskema",
    "Supported variables that will be dynamically replaced": "Dinamikoki ordezkatuko diren aldagaiak",
    "Symbol": "Ikurra",
    "Table": "Taula",
    "Text color for the cluster label": "Taldeko etiketaren testuko kolorea",
    "Text formatting": "Testuaren formatua",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Entitatearen etiketa gisa erabili beharreko propietatearen izena (adibidez: \"nom\"). Kortxeteen barneko propietateak ere erabil ditzakezu bat baino gehiago erabiltzeko edo eduki estatikoarekin nahasteko (adibidez: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Entitatearen identifikatzaile esklusibo gisa erabili beharreko propietatearen izena.",
    "The zoom and center have been modified.": "Zooma eta zentroa aldatu dira.",
    "TMS format": "TMS formatua",
    "To use if remote server doesn't allow cross domain (slower)": "Urruneko zerbitzariak domeinu gurutzatua onartzen ez badu erabiltzeko (motelago)",
    "To zoom": "Zooma egiteko",
    "Toggle edit mode (⇧+Click)": "Aldatu editatzeko modua (⇧+Klik)",
    "Toggle edit mode": "Aldatu editatzeko modua",
    "Transfer shape to edited feature": "Transferitu forma editatutako entitatera",
    "Transform to lines": "Lerroak bihurtu",
    "Transform to polygon": "Poligono bihurtu",
    "Type a place name or coordinates": "Idatzi leku-izena edo koordenatuak",
    "Type char or paste emoji": "Idatzi karakterea edo itsatsi emojia",
    "Type of layer": "Geruza mota",
    "Unable to detect format of file {filename}": "Ezin da hauteman {filename} fitxategiaren formatua",
    "Untitled layer": "Izenik gabeko geruza",
    "Untitled map": "Izenik gabeko mapa",
    "Update permissions and editors": "Eguneratu baimenak eta editoreak",
    "Update permissions": "Eguneratu baimenak",
    "Update who can see and edit the map": "Eguneratu mapa nork ikusi eta edita dezakeen",
    "Url": "Url-a",
    "URL": "URLa",
    "Use current bounds": "Erabili uneko mugak",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Erabili parentesi artean entitateen propietateak dituzten leku-markak, adibidez. {izena}, dagozkien balioekin dinamikoki ordezkatuko dira.",
    "User content credits": "Erabiltzaileen edukien kredituak",
    "User interface options": "Erabiltzailearen interfazearen aukerak",
    "User location": "Erabiltzailearen kokapena",
    "Verify remote URL": "Egiaztatu urruneko URLa",
    "Versions": "Bertsioak",
    "View Fullscreen": "Ikusi pantaila osoan",
    "View": "Ikuspegia",
    "Visibility: {status}": "Ikusgarritasuna: {egoera}",
    "weight": "pisua",
    "Where do we go from here?": "Hemendik nora joan behar dugu?",
    "Whether to display or not polygons paths.": "Poligonoen bideak bistaratu ala ez.",
    "Whether to fill polygons with color.": "Poligonoak kolorez bete behar diren ala ez.",
    "Who can edit \"{layer}\"": "Nork edita dezake \"{layer}\"",
    "Who can edit": "Nork edita dezake",
    "Who can view": "Nork ikus dezake",
    "width": "zabalera",
    "Will be displayed in the bottom right corner of the map": "Maparen beheko eskuineko izkinan bistaratuko da",
    "Will be permanently visible in the bottom left corner of the map": "Beti ikusgai egongo da maparen beheko ezkerreko izkinan",
    "Will be visible in the caption of the map": "Maparen epigrafean ikusiko da",
    "yes": "bai",
    "Zoom in": "Handiagotu",
    "Zoom level for automatic zooms": "Zoom-maila zoom automatikoetarako",
    "Zoom out": "Txikiagotu",
    "Zoom to layer extent": "Zoom egin geruzaren neurrira",
    "Zoom to the next": "Zooma hurrengora",
    "Zoom to the previous": "Zoom aurrekora",
    "Zoom to this feature": "Egin zoom entitate honetan",
    "Zoom to this place": "Handitu toki honetara",
    "{area}&#8239;acres": "{area} akre",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errore inportatzean: {message}",
    "{delay} seconds": "{delay} segundo",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} mila",
    "{distance}&#8239;NM": "{distance} itsas mila",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Editatu maparen izena eta epigrafea",
    "Map advanced properties": "Maparen propietate aurreratuak",
    "Edit map details": "Editatu maparen xehetasunak",
    "Back to browser": "Itzuli nabigatzailera",
    "Toggle size": "Aldatu tamaina",
    "Display the caption control": "Erakutsi azpitituluaren kontrola",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "Nondik",
    "Until": "Noraino",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Adibidea: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Editatu OpenStreetMap-en",
    "Cannot determine latitude and longitude columns.": "Ezin dira zehaztu latitude eta longitudearen zutabeak.",
    "Back to layers": "Itzuli geruzetara",
    "Filters": "Iragazkiak",
    "Comma separated list of properties to use when filtering features by text input": "Testu sarreren bidez entitateak iragazteko erabili beharreko propietateen zerrenda komaz bereizita",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Iragazteko erabili beharreko propietateen zerrenda komaz bereizita  (adib.: niregakoa,bestegakoa). Etiketa kontrolatzeko, gehitu | (adib.: niregakoa|niregakoa,bestegakoa|beste gakoa). Sarrera-eremu mota kontrolatzeko, gehitu beste | (adib.: nire gakoa|Nire gakoa|kontrol-laukia,bestegakoa|Beste gakoa|data-ordua). Sarrera-eremu motarako baimendutako balioak kontrol-laukia (lehenetsia), irratia, zenbakia, data eta data-ordua dira.",
    "Search keys": "Bilatu gakoak",
    "Filters keys": "Iragazkien gakoak",
    "Filter data": "Iragazi datuak",
    "Search map features…": "Bilatu maparen entitateak...",
    "Reset all": "Berrezarri dena",
    "Open browser": "Ireki arakatzailea",
    "Open caption": "Ireki epigrafea",
    "Your map has been created with an anonymous account!": "Zure mapa kontu anonimo batekin sortu da!",
    "Real-time collaboration": "Denbora errealeko lankidetza",
    "Cannot parse data": "Ezin dira datuak analizatu",
    "Start typing...": "Hasi idazten...",
    "No result": "Emaitzarik ez",
    "Data browser": "Datu arakatzailea",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "URL bat ematerakoan, uMap-ek urruneko datuak geruza batean kopiatu ditzake, edo URL hau gehitu geruzaren urruneko iturri gisa. Kasu horretan, datuak beti URL horretatik eskuratuko dira, eta horrela eguneratuta egongo dira, baina ezin izango da editatu uMap-en barruan.",
    "Overpass supported expressions": "Overpass onartzen duten esamoldeak",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Overpass sintaxiari buruzko informazio gehiago",
    "For more complex needs, see": "Behar konplexuagoetarako, ikusi",
    "Choose data": "Aukeratu datuak",
    "Import helpers:": "Inportatu laguntzaileak:",
    "Choose the format": "Aukeratu formatua",
    "Choose the layer": "Aukeratu geruza",
    "Layer name": "Geruzaren izena",
    "Choose import mode": "Aukeratu inportatzeko modua",
    "Copy into the layer": "Kopiatu geruzan",
    "Link to the layer as remote data": "Estekatu geruza urruneko datu gisa",
    "Condition": "Baldintza",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Ziur arau hau ezabatu nahi duzula?",
    "empty rule": "arau hutsa",
    "Conditional style rules": "Baldintzapeko estiloko arauak",
    "Add rule": "Gehitu araua",
    "Browser: data": "Arakatzailea: datuak",
    "Browser: layers": "Arakatzailea: geruzak",
    "Browser: filters": "Arakatzailea: iragazkiak",
    "Enable real-time collaboration": "Gaitu denbora errealeko lankidetza",
    "✅ Copied!": "✅ Kopiatuta!",
    "Choose a dataset": "Aukeratu datu-multzo bat",
    "Choose this dataset": "Aukeratu datu-multzo hau",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: OpenStreetMap-eko datu tematikoak",
    "Choose a theme": "Aukeratu gai bat",
    "Symplify all geometries to points": "Sinplifikatu geometria guztiak puntutan",
    "Choose this data": "Aukeratu datu hauek",
    "Search admin boundary": "Bilatu muga administratiboa",
    "Please choose a theme and a boundary first.": "Aukeratu gai bat eta muga bat.",
    "Expression": "Esamoldea",
    "Geometry mode": "Geometria modua",
    "Only geometry centers": "Geometria zentroak bakarrik",
    "Search area": "Bilatu eremua",
    "Type area name, or let empty to load data in current map view": "Idatzi eremuaren izena edo utzi hutsik datuak kargatzeko uneko maparen ikuspegian",
    "Data successfully imported!": "Datuak behar bezala inportatu dira!",
    "Clear data": "Garbitu datuak",
    "Remove layers": "Kendu geruzak",
    "Categorized": "Sailkatuta",
    "Alphabetical": "Alfabetikoa",
    "Category property": "Kategoriaren propietatea",
    "Color palette": "Kolore paleta",
    "Categories": "Kategoriak",
    "Comma separated list of categories.": "Komaz bereizitako kategorien zerrenda.",
    "Categories mode": "Kategoriak modua",
    "Remove filter for this column": "Kendu iragazkia zutabe honetarako",
    "Add filter for this column": "Gehitu iragazkia zutabe honetarako",
    "Rename this column": "Aldatu izena zutabe honi",
    "Delete this column": "Ezabatu zutabe hau",
    "Name “{name}” should not contain a dot.": "\"{name}\" izenak ez luke punturik izan behar.",
    "This name already exists: “{name}”": "Izen hau dagoeneko badago: “{name}”",
    "Delete selected rows": "Ezabatu hautatutako errenkadak",
    "Found {count} rows. Are you sure you want to delete all?": "{count} errenkada aurkitu dira. Ziur guztiak ezabatu nahi dituzula?",
    "Expression is empty": "Esamoldea hutsa dago",
    "OK": "Ados",
    "Cancel": "Utzi",
    "Attach map to a team": "Erantsi mapa talde bati",
    "Display the polygon inverted": "Bistaratu poligonoa alderantziz",
    "Proportional circles": "Zirkulu proportzionalak",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Zirkuluaren gutxieneko erradioa",
    "Max circle radius": "Zirkuluaren gehieneko erradioa",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Kopiatu GeoJSON gisa",
    "Please zoom in to edit the geometry": "Mesedez, handitu geometria editatzeko",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators"
}
L.registerLocale("eu", locale)
L.setLocale("eu")
